@@ -3,6 +3,7 @@ from os import makedirs
 from os.path import exists,abspath,join
 from subprocess import Popen,PIPE,STDOUT
 from pandas.api.types import is_numeric_dtype
+from time import sleep
 import sys
 
 
@@ -81,9 +82,18 @@ def format_table(writer, data, sheet_name,width=None,total_line:bool=False):
     rows = len(data)
     cols = len(data.columns)-1
     columns=[]
+
+    # Add a custom number format with commas to the workbook
+    comma_format = workbook.add_format({'num_format': '#,##0'})
+
     first=True
     for col_num, value in enumerate(data.columns.values):
         json = {'header': value}
+        
+        # Check if the column is numeric and not boolean
+        if is_numeric_dtype(data[value]) and data[value].dtype != 'bool':
+            json['format'] = comma_format
+
         if first:
             first=False
             if total_line:
@@ -124,8 +134,8 @@ def format_table(writer, data, sheet_name,width=None,total_line:bool=False):
     for col_num, value in enumerate(data.columns.values):
         worksheet.write(0, col_num, value, header_format)
         w=width[col_num]
-        worksheet.set_column(col_num, col_num, w)
-
+        worksheet.set_column(col_num, col_num, w, comma_format if is_numeric_dtype(data[value]) and data[value].dtype != 'bool' else None)
+        
     return worksheet
 
 def find_nth(string, substring, n):
@@ -197,15 +207,23 @@ def check_process(process:Popen,output=True):
             print(line)
         ret.append(line)
     stdout, stderr = process.communicate()
+    if not stdout is None and len(stdout): ret.append(stdout)
+    if not stderr is None and len(stderr): ret.append(stderr)
     return process.returncode,ret
-    
+
+def track_process(proc):
+    if proc.poll() is None:
+        while line := proc.stdout.readline():
+            print(line.replace('\n','                                               '),end='\r')
+            sleep(.5)
+
 
 def convert_LOC(total:int):
     unit = ''
     if 1000 <= total <= 1000000:
-        unit = 'KLoc'
+        unit = 'KLOC'
         total = int(total/1000)
     elif total > 1000000:
-        unit = 'MLoc'
+        unit = 'MLOC'
         total = round(total/1000000,1)
     return total,unit
\ No newline at end of file
